Changes proposed in this pull request:

-
-
- _Add screenshots for proposed visual changes_

  **Checklist**

- [ ] Unit tests are added for new features and bug fixes
- [ ] Documentation is added for new features
- [ ] Title of the pull request is self-explaining
